@@ -4,7 +4,7 @@ stabilitymenu<-function()
 cat("\n")
   file.menu <- c("Decision Tree for Data Evaluation",
                  "Statistical Approaches to Stability Data Analysis",
-                 "Back to Go menu",
+                 "Back to Top menu",
                  "Quit")
 cat("\n")
   pick <- menu(file.menu, title = " << Stability menu >> ")
@@ -25,7 +25,7 @@ cat("\n")
 
     else {
     if (pick == 4){
-        cat("\nBye~~ \n\n")}
+        cat("\nThanks for using stab for R. Bye now. \n\n")}
          }
      }
   }
